package com.huiju.estateagents.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.bo.request.HousingRaiseRequestBO;
import com.huiju.estateagents.bo.request.RaiseOrderRequestBO;
import com.huiju.estateagents.bo.request.RaiseRecordRequestBO;
import com.huiju.estateagents.entity.TaRaiseRecord;
import com.huiju.estateagents.mapper.TaRaiseRecordMapper;
import com.huiju.estateagents.po.TaHousingResourcesPO;
import com.huiju.estateagents.service.ITaRaiseRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * <p>
 * 认筹单(认筹记录表)  服务实现类
 * </p>
 *
 * @author jobob
 * @since 2020-02-26
 */
@Service
public class TaRaiseRecordServiceImpl extends ServiceImpl<TaRaiseRecordMapper, TaRaiseRecord> implements ITaRaiseRecordService {

    private Logger logger = LoggerFactory.getLogger(TaRaiseRecordServiceImpl.class);

    @Autowired
    private TaRaiseRecordMapper taRaiseRecordMapper;

    @Override
    public ResponseBean listHousingRaiseByCondition(HousingRaiseRequestBO requestBO, Integer pageNumber, Integer pageSize) {
        logger.info("TaRaiseRecordServiceImpl.listRaiseRecordByCondition 接收参数：bo:{},pageNumber:{},pageSize:{}", JSONObject.toJSONString(requestBO), pageNumber, pageSize);

        ResponseBean responseBean = new ResponseBean();
        IPage<TaHousingResourcesPO> pg = new Page<>(pageNumber, pageSize);
        responseBean.addSuccess(taRaiseRecordMapper.listHousingRaiseByCondition(pg, requestBO));
        return responseBean;
    }

    @Override
    public ResponseBean listRaiseRecordByCondition(RaiseRecordRequestBO recordRequestBO, Integer pageNumber, Integer pageSize) {
        logger.info("TaRaiseRecordServiceImpl.listRaiseRecordByCondition 接收参数：bo:{},pageNumber:{},pageSize:{}", JSONObject.toJSONString(recordRequestBO), pageNumber, pageSize);

        ResponseBean responseBean = new ResponseBean();
        IPage<TaRaiseRecord> pg = new Page<>(pageNumber, pageSize);
        responseBean.addSuccess(taRaiseRecordMapper.listRaiseRecordByCondition(pg, recordRequestBO));
        return responseBean;
    }

    @Override
    public ResponseBean listRaiseOrderByCondition(RaiseOrderRequestBO orderRequestBO, Integer pageNumber, Integer pageSize) {
        logger.info("TaRaiseRecordServiceImpl.listOrderByCondition 接收参数：bo:{},pageNumber:{},pageSize:{}", JSONObject.toJSONString(orderRequestBO), pageNumber, pageSize);

        ResponseBean responseBean = new ResponseBean();
        IPage<TaRaiseRecord> pg = new Page<>(pageNumber, pageSize);
        responseBean.addSuccess(taRaiseRecordMapper.listRaiseOrderByCondition(pg, orderRequestBO));
        return responseBean;
    }
}
